@@ -1,14 +1,14 @@
 from . import confusion_matrix
 from .colors import color_scheme, get_legend_handles
-from .data import classwise_mean, classwise_random
+from .data import get_file_from_google
 from .utils import (accuracy_score, class_histogram, make_directory, memoize,
                     ntimer, predict_and_score, prettify_string, pretty_print,
                     progressbar, remove_nan_cols, remove_nan_rows, replace_in,
                     start_tensorboard, train_test_split)
 
 __all__ = [
-    'accuracy_score', 'class_histogram', 'classwise_mean', 'classwise_random',
-    'color_scheme', 'get_legend_handles', 'make_directory', 'ntimer',
+    'accuracy_score', 'class_histogram', 'color_scheme',
+    'get_file_from_google', 'get_legend_handles', 'make_directory', 'ntimer',
     'predict_and_score', 'prettify_string', 'pretty_print', 'progressbar',
     'remove_nan_cols', 'remove_nan_rows', 'replace_in', 'start_tensorboard',
     'train_test_split', 'confusion_matrix', 'memoize'
